import { UploadUserFile } from '@bole-core/components';
import { CustomerApplyFileTypeListItem } from './utils';
import {
  ApplyTransferFileBusinessTypeEnum,
  FourStreamsMaterialFileBusinessTypeEnum,
  TransferFileEnumInRewardGrand,
} from '@/constants';

export type FourStreamsMaterialFileTableProps = {
  date?: string;
  showUploadBtn?: boolean;
  showCheckBtn?: boolean;
  showDownloadBtn?: boolean;
  showDeleteBtn?: boolean;
  downloadBtnText?: string;
  onDelete?: (row: CustomerApplyFileTypeListItem, fileId: string) => Promise<any>;
  onUpload?: (row: CustomerApplyFileTypeListItem, userFile: UploadUserFile) => Promise<any>;
};

export type BaseMaterialFileTableItem<T> = {
  fileBusinessType: T;
  fileList: UploadUserFile[];
};

export type FourStreamsMaterialFileTableItem =
  BaseMaterialFileTableItem<FourStreamsMaterialFileBusinessTypeEnum>;

export type ApplyTransferMaterialFileTableItem =
  BaseMaterialFileTableItem<ApplyTransferFileBusinessTypeEnum>;

export type TransferFileEnumInRewardGrandTableItem =
  BaseMaterialFileTableItem<TransferFileEnumInRewardGrand>;

export enum EnterpriseTypeEnum {
  /**
   * 人力资源公司
   */
  HREnterprise = 10,
  /**
   * 甲方企业
   */
  FirstPartyCompany = 20,
  /**
   * 行业配套
   */
  IndustryMating = 30,
  /**
   * 行业机构
   */
  IndustryBody = 40,
}

export const EnterpriseTypeEnumText = {
  [EnterpriseTypeEnum.HREnterprise]: '人力资源公司',
  [EnterpriseTypeEnum.FirstPartyCompany]: '甲方企业',
  [EnterpriseTypeEnum.IndustryMating]: '行业配套',
  [EnterpriseTypeEnum.IndustryBody]: '行业机构',
};
